import json
import os

with open(os.path.join(os.path.dirname(__file__), "data_file.json"), encoding="utf-8") as f_p:
    DATA_DICT = json.load(f_p)

_DATA2_DICT = None

def delay_data():
    global _DATA2_DICT
    if _DATA2_DICT is not None:
        return _DATA2_DICT

    import toml

    _DATA2_DICT = toml.load(os.path.join(os.path.dirname(__file__), "data_file_2.toml"))
    return _DATA2_DICT


import numpy as np

from ._data import DATA_DICT, delay_data

def some_calculation_function():
    return np.zeros((DATA_DICT["important_value1"], DATA_DICT["important_value2"]))


def some_calculation_function2():
    data = delay_data()
    return data["Section 1"]["data_point"] + data["Section 2"]["data_point"]